from distutils.core import setup
setup(
  name='aframetour',
  packages=['aframetour'],
  version='0.1.6',
  license='MIT',
  description='This library generates a web vr tour for a given zip file and grid size',
  author='Gaurav Dharra, Rob Wallace',
  author_email='gdharra2@illinois.edu',
  url='https://github.com/Grainger-Engineering-Library/vrticl',
  download_url='https://github.com/Grainger-Engineering-Library/vrticl.git',
  keywords=['WEB VR', 'AFRAME'],
  install_requires=[
      ],
  classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.7',
  ],
)
